ZXingLight
==========

|build-status| |docs-status|

A simple wrapper for `ZXing C++`_ inspired by zbarlight_.

Documentation is available on <https://zxinglight.readthedocs.io/en/latest/>.

.. _ZXing C++: https://github.com/glassechidna/zxing-cpp
.. _zbarlight: https://github.com/Polyconseil/zbarlight


.. |build-status| image:: https://travis-ci.org/Lubo/zxinglight.svg?branch=master
    :alt: Build status
    :target: https://travis-ci.org/Lubo/zxinglight
.. |docs-status| image:: https://readthedocs.org/projects/zxinglight/badge/?version=latest
    :alt: Documentation status
    :target: https://zxinglight.readthedocs.io/en/latest/
